@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_imagebuilder.type_defs import (
     CancelImageCreationResponseTypeDef,
@@ -75,23 +75,23 @@ __all__ = ("ImagebuilderClient",)
 
 
 class Exceptions:
-    CallRateLimitExceededException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ClientException: Boto3ClientError
-    ForbiddenException: Boto3ClientError
-    IdempotentParameterMismatchException: Boto3ClientError
-    InvalidPaginationTokenException: Boto3ClientError
-    InvalidParameterCombinationException: Boto3ClientError
-    InvalidParameterException: Boto3ClientError
-    InvalidParameterValueException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    InvalidVersionNumberException: Boto3ClientError
-    ResourceAlreadyExistsException: Boto3ClientError
-    ResourceDependencyException: Boto3ClientError
-    ResourceInUseException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceException: Boto3ClientError
-    ServiceUnavailableException: Boto3ClientError
+    CallRateLimitExceededException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ClientException: Type[Boto3ClientError]
+    ForbiddenException: Type[Boto3ClientError]
+    IdempotentParameterMismatchException: Type[Boto3ClientError]
+    InvalidPaginationTokenException: Type[Boto3ClientError]
+    InvalidParameterCombinationException: Type[Boto3ClientError]
+    InvalidParameterException: Type[Boto3ClientError]
+    InvalidParameterValueException: Type[Boto3ClientError]
+    InvalidRequestException: Type[Boto3ClientError]
+    InvalidVersionNumberException: Type[Boto3ClientError]
+    ResourceAlreadyExistsException: Type[Boto3ClientError]
+    ResourceDependencyException: Type[Boto3ClientError]
+    ResourceInUseException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceException: Type[Boto3ClientError]
+    ServiceUnavailableException: Type[Boto3ClientError]
 
 
 class ImagebuilderClient:
